@@ -2,7 +2,7 @@ package Test2::EventFacet::Coverage;
 use strict;
 use warnings;
 
-our $VERSION = '0.000013';
+our $VERSION = '0.000014';
 
 BEGIN { require Test2::EventFacet; our @ISA = qw(Test2::EventFacet) }
 use Test2::Util::HashBase qw{ files submap openmap };
@@ -50,29 +50,16 @@ C<open()>.
             # The wildcard is used when a proper sub name cannot be determined
             '*' => { ... },
 
-            'SomeModule::subroutine' => {
-                sub_package => 'SomeModule',
-                sub_name    => 'subroutine',
-
-                call_count => $INTEGER,
-
-                # The items in this list can be anything, strings, numbers,
-                # data structures, etc.
-                # A naive attempt is made to avoid duplicates in this list,
-                # so the same string or reference will not appear twice, but 2
-                # different references with identical contents may appear.
-                called_by => [
-                    '*',     # The wildcard is used when no 'called by' can be determined
-                    $FROM_A,
-                    $FROM_B,
-                    ...
-                ],
-            },
+            'subroutine' => [
+                '*',     # The wildcard is used when no 'called by' can be determined
+                $FROM_A,
+                $FROM_B,
+                ...
+            ],
         },
         ...
     }
 
-
 =item $hashref = $about->{openmap}
 
 =item $hashref = $about->openmap()
